@@ -436,7 +436,7 @@ class Inverted(Linear):
         self.VAL_ARR2NPY = {'f': np.single, 'd': np.double}
 
         self.IDX_NPY_TYPE = self.IDX_ARR2NPY[self.IDX_ARR_TYPE][
-            array.array(self.IDX_ARR_TYPE).itemsize()]
+            array.array(self.IDX_ARR_TYPE).itemsize]
         self.VAL_NPY_TYPE = self.VAL_ARR2NPY[self.VAL_ARR_TYPE]
 
         self.idxs = []
